/**
    @file ft51_general_config_device_initialise.c

    @brief General Configuration Library API initialise function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdlib.h>
#include "ft51.h"
#include "ft51_general_config.h"
#include "ft51_sfr.h"
#include "ft51_io_registers.h"
#include "registers/ft51_registers.h"
#include "registers/ft51_iomux_registers.h"

void device_initialise(void)
{
    /* Zero high half of IO register addresses so that most code needs to
     * only set the low half.  (Except IO cell controller: see io_register.h)
     */
    IO_ADDR_0_H = IO_ADDR_1_H = IO_ADDR_2_H = IO_ADDR_3_H = IO_ADDR_4_H =
            IO_ADDR_5_H = IO_ADDR_6_H = IO_ADDR_7_H = IO_ADDR_8_H =
                    IO_ADDR_9_H = 0;

    // Enable access to on-chip peripherals (SPI, UART etc.)
    IO_REG_GENERAL_WRITE(DEVICE_CONTROL_REGISTER, MASK_TOP_DEV_EN);

    // Enable IOMUX controller so that signals may be routed to pads
    IO_REG_GENERAL_WRITE(IOMUX_CONTROL, MASK_IOMUX_DEV_EN);
}